@@ -7,7 +7,7 @@
 #include "charpick.h"
 
 
-static charpick_button_cb_data button_cb_data[MAX_BUTTONS];
+static charpick_button_cb_data button_cb_data[MAX_BUTTONS_WITH_BUFFER];
 charpick_data curr_data;
 
 /* This stuff assumes that this program is being run in an environment
@@ -97,6 +97,9 @@ charpick_selection_handler(GtkWidget *widget,
 			 8,
 			 &p_curr_data->selected_char,
 			 1);
+  return;
+  info = time = 0;
+  widget = NULL;
 }
 
 /* untoggles the active toggle_button when we lose the selection */
@@ -109,21 +112,71 @@ selection_clear_cb (GtkWidget *widget, GdkEventSelection *event,
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(toggle_button), FALSE);
   *last_index = NO_LAST_INDEX;
   return TRUE;
+  widget = NULL;
+  event = NULL;
+  have_selection = NULL;
 }
 
+/* this sets up the rows and columns according to the panel size and
+   settings as appropriate */
+static void
+setup_rows_cols(charpick_data *p_curr_data, gint *rows, gint *cols)
+{
+  if (p_curr_data->properties->follow_panel_size)
+  {
+    int r,c;
+    /* for vertical we only take 2/3 of the size as that is what is
+       then used for the table */
+    if (p_curr_data->panel_vertical)
+      r = (p_curr_data->panel_size * 3) / (p_curr_data->properties->size * 2);
+    else
+      r = p_curr_data->panel_size / p_curr_data->properties->size;
+
+    if (r < 1)
+      r = 1;
+    else if (r > p_curr_data->properties->min_cells)
+      r = p_curr_data->properties->min_cells;
+
+    if (p_curr_data->properties->min_cells % r == 0)
+      c = p_curr_data->properties->min_cells / r;
+    else
+      c = (p_curr_data->properties->min_cells / r) + 1;
+      
+    if (p_curr_data->panel_vertical)
+    {
+      *rows = c;
+      *cols = r;
+    }
+    else
+    {
+      *rows = r;
+      *cols = c;
+    }
+  }
+  else
+  {
+    *rows = p_curr_data->properties->rows;
+    *cols = p_curr_data->properties->cols;
+  }
+}
+
+
 /* displays a list of characters in labels on buttons*/
 static void
 display_charlist (charpick_data *data)
 {
-  gint rows = data->properties->rows;
-  gint cols = data->properties->cols;
+  guint rows;
+  guint cols;
   const gchar *charlist = data->charlist;
-
   /* let's show no more characters than we have, or than we have space for. */
-  gint numtoshow = MIN(rows * cols, strlen(charlist));
-  gint i = 0; /* loop variable */
+  guint numtoshow;
+  guint i = 0; /* loop variable */
   gchar currstr[2];
 
+  setup_rows_cols (data, &rows, &cols);
+
+  numtoshow = MIN(rows * cols, strlen(charlist));
+
   /* reset the characters on the labels and reshow the buttons */
   for (i=0;i<numtoshow;i++)
   {
@@ -162,6 +215,7 @@ toggle_button_toggled_cb(GtkWidget *widget, gpointer data)
   cb_data->p_curr_data->last_index = button_index;
   }		     
   return TRUE;
+  widget = NULL;
 }
 
 /* clicks on the toggle buttons with mouse buttons other than 1 go to the 
@@ -175,6 +229,7 @@ button_press_cb (GtkWidget *widget, GdkEventButton *event)
     return gtk_widget_event (curr_data.applet, (GdkEvent *)event);
   }
   return TRUE;
+  widget = NULL;
 }
 
 static gint
@@ -268,9 +323,9 @@ key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
   p_curr_data->last_index = NO_LAST_INDEX;
   display_charlist(p_curr_data);
   return TRUE;
+  widget = NULL;
 }
 
-
 /* creates table of buttons, sets up their callbacks, and packs the table in
    the event box */
 
@@ -283,12 +338,13 @@ build_table(charpick_data *p_curr_data)
   GtkWidget * *label;
   gint rows, cols, size;
   gint i;
-  rows = p_curr_data->properties->rows;
-  cols = p_curr_data->properties->cols;
   size = p_curr_data->properties->size;
+
+  setup_rows_cols (p_curr_data, &rows, &cols);
+
   toggle_button = p_curr_data->toggle_buttons;
   label = p_curr_data->labels;
-  /*for (i=0;i<MAX_BUTTONS;i++)*/
+  /*for (i=0;i<MAX_BUTTONS_WITH_BUFFER;i++)*/
   if (table)
     gtk_widget_destroy(table);
   table = gtk_table_new (rows, cols, TRUE);
@@ -341,6 +397,29 @@ static gint applet_save_session(GtkWidget *widget, char *privcfgpath,
   /*charpick_persistant_properties *properties = data;*/
   property_save(privcfgpath, curr_data.properties);
   return FALSE;
+  widget = NULL;
+  globcfgpath  = NULL;
+  data = NULL;
+}
+
+static void applet_change_pixel_size(GtkWidget *widget, int size)
+{
+  curr_data.panel_size = size;
+  build_table (&curr_data);
+  return;
+  widget = NULL;
+}
+
+static void applet_change_orient(GtkWidget *widget, PanelOrientType o)
+{
+  if (o == ORIENT_UP ||
+      o == ORIENT_DOWN)
+    curr_data.panel_vertical = FALSE;
+  else
+    curr_data.panel_vertical = TRUE;
+  build_table (&curr_data);
+  return;
+  widget = NULL;
 }
 
 static void
@@ -360,6 +439,9 @@ about (AppletWidget *applet, gpointer data)
 
   gtk_window_set_modal (GTK_WINDOW(about_box),TRUE);
   gnome_dialog_run (GNOME_DIALOG (about_box));
+  return;
+  applet = NULL;
+  data = NULL;
 }
 
 int
@@ -369,9 +451,8 @@ main (int argc, char *argv[])
   GtkWidget *frame = NULL;
   GtkWidget *event_box = NULL;
   GtkWidget *table = NULL;
-  GtkWidget *toggle_button[MAX_BUTTONS];
-  GtkWidget *label[MAX_BUTTONS];
-  gint rows, cols;
+  GtkWidget *toggle_button[MAX_BUTTONS_WITH_BUFFER];
+  GtkWidget *label[MAX_BUTTONS_WITH_BUFFER];
   /* initialize properties. when sm is added, these will be loaded
    * rather than simply copied from the defaults.
    */
@@ -379,9 +460,12 @@ main (int argc, char *argv[])
   charpick_persistant_properties default_properties = 
   {
     NULL, /* a_list */
+    TRUE,
+    8,
     2,
     2,
-    17
+    17,
+
   };
   /*
   charpick_data curr_data =
@@ -409,8 +493,6 @@ main (int argc, char *argv[])
   curr_data.frame = frame;
   curr_data.applet = applet;
   curr_data.properties = &default_properties;
-  rows = default_properties.rows;
-  cols = default_properties.cols;
 
 
   /* Initialize the i18n stuff */
@@ -468,6 +550,10 @@ main (int argc, char *argv[])
   gtk_signal_connect(GTK_OBJECT(applet),"save_session",
 		     GTK_SIGNAL_FUNC(applet_save_session), 
                      &default_properties);
+  gtk_signal_connect(GTK_OBJECT(applet),"change_pixel_size",
+		     GTK_SIGNAL_FUNC(applet_change_pixel_size), NULL);
+  gtk_signal_connect(GTK_OBJECT(applet),"change_orient",
+		     GTK_SIGNAL_FUNC(applet_change_orient), NULL);
 
   applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 				         "about",
