@@ -83,6 +83,8 @@ static void pixmap_floppy_cb(GtkWidget *widget, gpointer data)
 	dd->prop_device_pixmap = 0;
 	set_icon_entry_sensitivity(dd, FALSE);
         gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+	return;
+	widget = NULL;
 }
 
 static void pixmap_cdrom_cb(GtkWidget *widget, gpointer data)
@@ -91,6 +93,8 @@ static void pixmap_cdrom_cb(GtkWidget *widget, gpointer data)
 	dd->prop_device_pixmap = 1;
 	set_icon_entry_sensitivity(dd, FALSE);
         gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+        return;
+        widget = NULL;
 }
 
 static void pixmap_zipdrive_cb(GtkWidget *widget, gpointer data)
@@ -99,6 +103,8 @@ static void pixmap_zipdrive_cb(GtkWidget *widget, gpointer data)
 	dd->prop_device_pixmap = 2;
 	set_icon_entry_sensitivity(dd, FALSE);
         gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+        return;
+        widget = NULL;
 }
 
 static void pixmap_jazdrive_cb(GtkWidget *widget, gpointer data)
@@ -107,6 +113,8 @@ static void pixmap_jazdrive_cb(GtkWidget *widget, gpointer data)
 	dd->prop_device_pixmap = 4;
 	set_icon_entry_sensitivity(dd, FALSE);
 	gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+        return;
+        widget = NULL;
 }
 
 static void pixmap_harddisk_cb(GtkWidget *widget, gpointer data)
@@ -115,6 +123,8 @@ static void pixmap_harddisk_cb(GtkWidget *widget, gpointer data)
 	dd->prop_device_pixmap = 3;
 	set_icon_entry_sensitivity(dd, FALSE);
         gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+        return;
+        widget = NULL;
 }
 
 static void pixmap_custom_cb(GtkWidget *widget, gpointer data)
@@ -123,6 +133,8 @@ static void pixmap_custom_cb(GtkWidget *widget, gpointer data)
 	dd->prop_device_pixmap = -1;
 	set_icon_entry_sensitivity(dd, TRUE);
         gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+        return;
+        widget = NULL;
 }
 
 static void update_delay_cb( GtkWidget *widget, gpointer data)
@@ -130,6 +142,8 @@ static void update_delay_cb( GtkWidget *widget, gpointer data)
 	DriveData *dd = data;
         dd->prop_interval = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(dd->prop_spin));
         gnome_property_box_changed(GNOME_PROPERTY_BOX(dd->propwindow));
+        return;
+        widget = NULL;
 }
 
 static void property_apply_cb( GtkWidget *widget, void *data, DriveData *dd)
@@ -157,12 +171,16 @@ static void property_apply_cb( GtkWidget *widget, void *data, DriveData *dd)
 
 	/*make the panel save our config*/
 	applet_widget_sync_config(APPLET_WIDGET(dd->applet));
+        return;
+        widget = NULL;
+	data = NULL;
 }
 
 static gint property_destroy_cb( GtkWidget *w, DriveData *dd)
 {
         dd->propwindow = NULL;
 	return FALSE;
+	w = NULL;
 }
 
 void property_show(AppletWidget *applet, gpointer data)
@@ -332,6 +350,8 @@ void property_show(AppletWidget *applet, gpointer data)
 			    GTK_SIGNAL_FUNC(gnome_help_pbox_display),
 			    &help_entry );
 
-        gtk_widget_show_all(dd->propwindow);
+	gtk_widget_show_all(dd->propwindow);
+	return;
+	applet = NULL;
 }
 
