@@ -34,7 +34,7 @@
 #include "message.h"
 
 static gint fileBrowserOK_signal(GtkWidget *widget, gpointer fileSelect);
-static gint historyItemClicked_cb(GtkWidget *widget, gpointer data);
+/*static gint historyItemClicked_cb(GtkWidget *widget, gpointer data);*/
 static gint historyPopupClicked_cb(GtkWidget *widget, gpointer data);
 static gint historyPopupClickedInside_cb(GtkWidget *widget, gpointer data);
 static void historySelectionMade_cb(GtkWidget *clist, gint row, gint column,
@@ -54,7 +54,6 @@ commandKey_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
     static char currentCommand[MAX_COMMAND_LENGTH];
     char buffer[MAX_COMMAND_LENGTH];
     int propagateEvent = TRUE;
-    int pos;
 
     /* printf("%d,%d,%d;  ", (gint16) event->keyval, event->state, event->length); */
 
@@ -159,6 +158,7 @@ commandKey_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 	    event->length = 0;  
 	}
     return (propagateEvent == FALSE);
+    data = NULL;
 }
 
 static gint
@@ -169,8 +169,12 @@ commandFocusOut_event(GtkWidget *widget, GdkEvent *event, gpointer data)
       gtk_widget_grab_focus(GTK_WIDGET(widget)); 
     */
     return (FALSE);
+    widget = NULL;
+    event = NULL;
+    data = NULL;
 }
 
+#if 0
 static gint
 activateCommandLine_signal(GtkWidget *widget, gpointer data)
 {
@@ -180,6 +184,7 @@ activateCommandLine_signal(GtkWidget *widget, gpointer data)
     /* go on */
     return (FALSE);
 }
+#endif
 
 /* no longer needed */
 static void
@@ -193,8 +198,12 @@ historySelectionMade_cb(GtkWidget *clist, gint row, gint column,
 
     /* close history window */
     gtk_widget_destroy(GTK_WIDGET(clist->parent->parent->parent));
+    return;
+    data = NULL;
+    event = NULL;
 }
 
+#if 0
 static gint
 historyItemClicked_cb(GtkWidget *widget, gpointer data)
 {
@@ -215,6 +224,7 @@ historyItemClicked_cb(GtkWidget *widget, gpointer data)
     /* go on */
     return (FALSE);
 }
+#endif
 
 static gint
 historyPopupClicked_cb(GtkWidget *widget, gpointer data)
@@ -226,6 +236,7 @@ historyPopupClicked_cb(GtkWidget *widget, gpointer data)
      
     /* go on */
     return (FALSE);
+    data = NULL;
 }
 
 static gint
@@ -233,6 +244,8 @@ historyPopupClickedInside_cb(GtkWidget *widget, gpointer data)
 {
     /* eat signal (prevent that popup will be destroyed) */
     return(TRUE);
+    widget = NULL;
+    data = NULL;
 }
 
 gint 
@@ -242,8 +255,7 @@ showHistory_signal(GtkWidget *widget, gpointer data)
      GtkWidget *frame;
      GtkWidget *scrolled_window;
      GtkWidget *clist;
-     GtkStyle *style;
-     GdkColor color;
+     /*GtkStyle *style;*/
      gchar *commandList[1];
      int i, j;
 
@@ -357,7 +369,9 @@ showHistory_signal(GtkWidget *widget, gpointer data)
      */
      
      /* go on */
-     return FALSE;  
+     return FALSE;
+     widget = NULL;
+     data = NULL;
 }
 
 static gint 
@@ -376,6 +390,7 @@ fileBrowserOK_signal(GtkWidget *widget, gpointer fileSelect)
 
     /* go on */
     return FALSE;  
+    widget = NULL;
 }
 
 gint 
@@ -411,7 +426,9 @@ showFileBrowser_signal(GtkWidget *widget, gpointer data)
     gtk_widget_show(fileSelect);
 
     /* go on */
-    return FALSE;  
+    return FALSE;
+    widget = NULL;
+    data = NULL;
 }
 
 void
@@ -446,7 +463,6 @@ void
 command_entry_update_color(void)
 {
     GtkStyle *style;
-    GdkColor color;
     
     /* change widget style */
     /* style = malloc(sizeof(GtkStyle)); */
@@ -469,7 +485,7 @@ command_entry_update_size(void)
 {
     int size_y = -1;
   
-    if(prop.flatLayout) 
+    if(prop.flatLayout)  {
 	if(prop.showHandle && !prop.showFrame)
 	    size_y = prop.normalSizeX - 17 - 10;
 	else if(!prop.showHandle && !prop.showFrame)
@@ -478,6 +494,7 @@ command_entry_update_size(void)
 	    size_y = prop.normalSizeX - 17 - 10 - 10;
 	else if(!prop.showHandle && prop.showFrame)
 	    size_y = prop.normalSizeX - 17 - 10;
+    }
 
     gtk_widget_set_usize(GTK_WIDGET(entryCommand), size_y, prop.cmdLineY);
 }
