@@ -21,6 +21,7 @@
 
 /* If you think this code is a mess, you should see my flat ;) */
 
+#include "config.h"
 #include "screenshooter_applet.h"
 
 /* TODO For the application launches...
@@ -35,7 +36,8 @@ cb_about (AppletWidget * widget, gpointer data)
   GtkWidget *my_url;
   static const char *authors[] =
     { "Tom Gilbert <gilbertt@tomgilbert.freeserve.co.uk>",
-    "The Sirius Cybernetics Corporation (Ursa-minor)", NULL
+    "Telsa Gwynne <hobbit@aloss.ukuu.org.uk> (typo fixes, documentation)",
+    "The Sirius Cybernetics Corporation <Ursa-minor>", NULL
   };
 
   about = gnome_about_new
@@ -52,7 +54,8 @@ cb_about (AppletWidget * widget, gpointer data)
   my_url = gnome_href_new ("http://www.tomgilbert.freeserve.co.uk",
 			   "Visit the author's Website");
   gtk_widget_show (my_url);
-  gtk_box_pack_start (GTK_BOX ((GNOME_DIALOG(about))->vbox), my_url, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX ((GNOME_DIALOG (about))->vbox), my_url, FALSE,
+		      FALSE, 0);
 
   gtk_widget_show (about);
   data = NULL;
@@ -119,6 +122,8 @@ properties_save (gchar * path, gpointer data)
   gnome_config_pop_prefix ();
   gnome_config_sync ();
   gnome_config_drop_all ();
+  return;
+  data = NULL;
 }
 
 static void
@@ -167,7 +172,7 @@ properties_load (gchar * path, gpointer data)
     g_strdup (gnome_config_get_string ("screenshooter/directory=~/"));
   options.filename =
     g_strdup (gnome_config_get_string
-	      ("screenshooter/filename=`date +%d-%m-%y_%H%M%S`_screenshot.jpg"));
+	      ("screenshooter/filename=`date +%Y_%m_%d_%H%M%S`_shot.jpg"));
   options.thumb_filename =
     g_strdup (gnome_config_get_string
 	      ("screenshooter/thumb_filename=thumb-"));
@@ -206,6 +211,8 @@ properties_load (gchar * path, gpointer data)
   options.thumbnail_intermediate =
     gnome_config_get_bool ("screenshooter/thumbnail_intermediate=FALSE");
   gnome_config_pop_prefix ();
+  return;
+  data = NULL;
 }
 
 void
@@ -309,8 +316,7 @@ cb_applet_change_orient (GtkWidget * w, PanelOrientType o, gpointer data)
 {
   gboolean size_tiny = FALSE;
 #ifdef HAVE_PANEL_PIXEL_SIZE
-  int panelsize =
-    applet_widget_get_panel_pixel_size (APPLET_WIDGET (applet));
+  int panelsize = applet_widget_get_panel_pixel_size (APPLET_WIDGET (applet));
   /* Switch stuff so it lies flat on a tiny panel */
   if (panelsize < PIXEL_SIZE_STANDARD)
     size_tiny = TRUE;
@@ -381,7 +387,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   button =
     gtk_check_button_new_with_label (_
-				     ("Capture WM decorations when grabbing a window?"));
+				     ("Capture WM decorations when grabbing a window"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->decoration);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) decoration_cb, NULL);
@@ -390,7 +396,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   button =
     gtk_check_button_new_with_label (_
-				     ("Give audio feedback using the keyboard bell?"));
+				     ("Give audio feedback using the keyboard bell"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->beep);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) beep_cb, NULL);
@@ -399,7 +405,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   button =
     gtk_check_button_new_with_label (_
-				     ("Display Spurious Options? (I got carried away)"));
+				     ("Display Spurious Options (I got carried away)"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->spurious);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) spurious_cb, NULL);
@@ -408,7 +414,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   frame =
     gtk_frame_new (_
-		   ("Delay (seconds) before taking shot (Only for entire desktop shots)"));
+		   ("Delay (seconds) before taking shot (only for entire desktop shots)"));
   gtk_box_pack_start (GTK_BOX (pref_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -430,7 +436,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   frame =
     gtk_frame_new (_
-		   ("Compression Quality (JPEG/MIFF/PNG Mode) High: good quality/large file"));
+		   ("Compressed Quality (JPEG/MIFF/PNG mode) High: good quality/large file"));
   gtk_box_pack_start (GTK_BOX (pref_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -455,7 +461,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_vbox), ad->spurious_pref_vbox3, FALSE,
 		      FALSE, 0);
 
-  button = gtk_check_button_new_with_label (_ ("Create Monochrome image?"));
+  button = gtk_check_button_new_with_label (_ ("Create monochrome image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->monochrome);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) monochrome_cb, NULL);
@@ -463,7 +469,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 		      0);
   gtk_widget_show (button);
 
-  button = gtk_check_button_new_with_label (_ ("Invert colours in image?"));
+  button = gtk_check_button_new_with_label (_ ("Invert colours in image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->negate);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) negate_cb, NULL);
@@ -490,9 +496,10 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   ad->directory_entry = gnome_file_entry_new ("output_dir",
 					      "Select directory");
-  gnome_file_entry_set_directory(GNOME_FILE_ENTRY(ad->directory_entry), TRUE);
+  gnome_file_entry_set_directory (GNOME_FILE_ENTRY (ad->directory_entry),
+				  TRUE);
   entry = GTK_COMBO (GNOME_FILE_ENTRY (ad->directory_entry)->gentry)->entry;
-  
+
   if (ad->directory)
     gtk_entry_set_text (GTK_ENTRY (entry), ad->directory);
 
@@ -504,23 +511,10 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 		      0);
   gtk_widget_show (ad->directory_entry);
 
-/* Directory selector button 
-  pref_hbox5 = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-  gtk_box_pack_start (GTK_BOX (pref_vbox), pref_hbox5, FALSE, FALSE, 0);
-  gtk_widget_show (pref_hbox5);
-  directory_button = gtk_button_new_with_label (_ ("Pick Directory..."));
-  gtk_signal_connect_object (GTK_OBJECT (directory_button), "clicked",
-			     GTK_SIGNAL_FUNC (directory_button_pressed),
-			     NULL);
-  gtk_box_pack_end (GTK_BOX (pref_hbox5), directory_button, FALSE, FALSE, 0);
-  gtk_widget_show (directory_button);
-  gtk_widget_show (pref_hbox5);
-  */
-
   pref_hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
   gtk_box_pack_start (GTK_BOX (pref_vbox), pref_hbox, FALSE, FALSE, 0);
   gtk_widget_show (pref_hbox);
-  label = gtk_label_new (_ ("Filename for images:"));
+  label = gtk_label_new (_ ("Image filename:"));
   gtk_box_pack_start (GTK_BOX (pref_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
@@ -535,6 +529,12 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_hbox), ad->filename_entry, TRUE, TRUE, 0);
   gtk_widget_show (ad->filename_entry);
 
+  button = gtk_button_new_with_label (_ ("Show expanded filename"));
+  gtk_signal_connect (GTK_OBJECT (button), "clicked",
+		      (GtkSignalFunc) expand_cb, NULL);
+  gtk_box_pack_start (GTK_BOX (pref_hbox), button, FALSE, FALSE, 0);
+  gtk_widget_show (button);
+
   frame = gtk_frame_new (NULL);
   gtk_box_pack_start (GTK_BOX (pref_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
@@ -550,19 +550,23 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (pref_hbox);
   label = gtk_label_new (_
 			 ("Filetype is determined from filename suffix.\n"
-			  "Default filetype (if no extension, or unrecognised extension) "
+			  "Default filetype (if no extension or unrecognised extension) "
 			  "is miff.\n"
 			  "Recognised suffixes are:\n"
 			  "jpg, jpeg, bmp, cgm, cmyk, dib, eps, fig, fpx, gif, ico, map, miff, pcx,\n"
 			  "pict, pix, png, pnm, ppm, psd, rgb, rgba, rla, rle, tiff, tga, xbm, xpm,\n"
 			  "and several obscure ones. Try your luck with something interesting!\n"
-			  "Eg .html for a client-side image map. You'll get a .gif, .html, and a .shtml"));
+			  "Eg .html for a client-side image map. You'll get a .gif, .html, and a .shtml\n\n"
+			  "Recommendations:\n"
+			  "Small file, pretty good quality:   jpg, 75% quality\n"
+			  "Slightly larger file but lossless: png, as much compression as you like.\n"
+			  "- compressing pngs takes longer at higher ratios, but is still lossless"));
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
   gtk_box_pack_start (GTK_BOX (pref_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
 
   button =
-    gtk_check_button_new_with_label (_ ("View screenshot after saving it?"));
+    gtk_check_button_new_with_label (_ ("View screenshot after saving it"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->view);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) view_cb, NULL);
@@ -597,7 +601,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_container_set_border_width (GTK_CONTAINER (pref_vbox), GNOME_PAD_SMALL);
 
   button =
-    gtk_check_button_new_with_label (_ ("Create Thumbnail of image too?"));
+    gtk_check_button_new_with_label (_ ("Create thumbnail of image too"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->thumb);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) thumb_cb, NULL);
@@ -605,7 +609,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (button);
 
 
-  frame = gtk_frame_new (_ ("Thumbnail Size (Percentage of original)"));
+  frame = gtk_frame_new (_ ("Thumbnail Size (percentage of original)"));
   gtk_box_pack_start (GTK_BOX (pref_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -626,7 +630,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   frame =
     gtk_frame_new (_
-		   ("Thumbnail Compression (JPEG/MIFF/PNG Mode) "
+		   ("Thumbnail compression (JPEG/MIFF/PNG mode) "
 		    "High: good quality/large file"));
   gtk_box_pack_start (GTK_BOX (pref_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
@@ -681,7 +685,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   button =
     gtk_check_button_new_with_label (_
 				     ("Use high-quality intermediate "
-				      "for generating thumbnail?"));
+				      "for generating thumbnail"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				ad->thumbnail_intermediate);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -694,10 +698,10 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (pref_hbox);
   label =
     gtk_label_new (_
-		   ("(This'll chug loads of cpu, but will prevent compressing the "
+		   ("(This'll chug loads of CPU, but will prevent compressing the "
 		    "image twice if a\nlossy file format is used)\n"
-		    "Don't use this if you're not using a lossy compression format, or"
-		    "if you cherish\nspeed, and don't mind imperfection in your thumbnails."));
+		    "Don't use this if you're using a lossless compression format, or "
+		    "if you cherish\nspeed and don't mind imperfection in your thumbnails."));
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
   gtk_box_pack_start (GTK_BOX (pref_hbox), label, FALSE, FALSE, 0);
 
@@ -725,9 +729,9 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   label =
     gtk_label_new (_
 		   ("All post-processing, frill and spurious options "
-		    "will chug more cpu than a\nsimple screenshot, "
+		    "will chug more CPU than a\nsimple screenshot, "
 		    "due to the creation and then conversion of an intermediate\n"
-		    "image. Intensive operations may take some time on less spiffy cpus."));
+		    "image. Intensive operations may take some time on less spiffy CPUs."));
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
   gtk_box_pack_start (GTK_BOX (pref_hbox), label, FALSE, FALSE, 0);
 
@@ -737,7 +741,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   button =
     gtk_check_button_new_with_label (_
-				     ("Normalize image? (Span full range of "
+				     ("Normalize image (Span full range of "
 				      "color values to enhance contrast)"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->normalize);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -747,7 +751,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   button =
     gtk_check_button_new_with_label (_
-				     ("Equalize image? (Perform "
+				     ("Equalize image (Perform "
 				      "histogram equalization)"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->equalize);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
@@ -760,7 +764,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (pref_hbox);
 
   button =
-    gtk_check_button_new_with_label (_ ("Enhance image? (Reduce noise)"));
+    gtk_check_button_new_with_label (_ ("Enhance image (reduce noise)"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->enhance);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) enhance_cb, NULL);
@@ -768,7 +772,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (button);
 
   button =
-    gtk_check_button_new_with_label (_ ("Despeckle Image? (Reduce Spots)"));
+    gtk_check_button_new_with_label (_ ("Despeckle Image (reduce spots)"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->despeckle);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) despeckle_cb, NULL);
@@ -813,7 +817,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_vbox_2), hscale, TRUE, TRUE, 0);
   gtk_widget_show (hscale);
 
-  button = gtk_check_button_new_with_label (_ ("Adjust gamma?"));
+  button = gtk_check_button_new_with_label (_ ("Adjust gamma"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->gamma);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) gamma_cb, NULL);
@@ -851,14 +855,14 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   pref_vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
   gtk_container_set_border_width (GTK_CONTAINER (pref_vbox), GNOME_PAD_SMALL);
 
-  button = gtk_check_button_new_with_label (_ ("Create Frame around image?"));
+  button = gtk_check_button_new_with_label (_ ("Create frame around image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->frame);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) frame_cb, NULL);
   gtk_box_pack_start (GTK_BOX (pref_vbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
-  frame = gtk_frame_new (_ ("Frame Width (Pixels)"));
+  frame = gtk_frame_new (_ ("Frame Width (pixels)"));
   gtk_box_pack_start (GTK_BOX (pref_vbox), frame, FALSE, FALSE, 0);
   gtk_widget_show (frame);
 
@@ -881,23 +885,21 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_vbox), pref_hbox, FALSE, FALSE, 0);
   gtk_widget_show (pref_hbox);
 
-  button =
-    gtk_check_button_new_with_label (_ ("Flip (mirror) image vertically?"));
+  button = gtk_check_button_new_with_label (_ ("Mirror image vertically"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->flip);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) flip_cb, NULL);
   gtk_box_pack_start (GTK_BOX (pref_hbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
-  button =
-    gtk_check_button_new_with_label (_ ("Flip (mirror) image horizontally?"));
+  button = gtk_check_button_new_with_label (_ ("Mirror image horizontally"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->flop);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) flop_cb, NULL);
   gtk_box_pack_start (GTK_BOX (pref_hbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
-  button = gtk_check_button_new_with_label (_ ("Emboss image?"));
+  button = gtk_check_button_new_with_label (_ ("Emboss image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->emboss);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) emboss_cb, NULL);
@@ -917,7 +919,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   button =
     gtk_check_button_new_with_label (_
 				     ("When finished, send image and "
-				      "thumbnail filenames to script/program below?"));
+				      "thumbnail filenames to script/program below"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->use_script);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) use_script_cb, NULL);
@@ -949,11 +951,11 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 
   label =
     gtk_label_new (_
-		   ("Script/Program will be launched after image creation, with the "
+		   ("Script/program will be launched after image creation with the "
 		    "image filenames\nspecified on the commandline as follows:\n"
 		    "{Script_Name} {Image_Filename} {Thumbnail_filename_if_specified}\n"
 		    "Hint: I use a script to update my website screenshot page.\n"
-		    "An example script should have included in the tarball, or at my website."));
+		    "An example script should've been included in the tarball, or at my website."));
   gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
   gtk_box_pack_start (GTK_BOX (pref_hbox), label, FALSE, FALSE, 0);
   gtk_widget_show (label);
@@ -967,7 +969,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_container_set_border_width (GTK_CONTAINER (ad->spurious_pref_vbox),
 				  GNOME_PAD_SMALL);
 
-  button = gtk_check_button_new_with_label (_ ("Blur Image?"));
+  button = gtk_check_button_new_with_label (_ ("Blur Image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->blur);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) blur_cb, NULL);
@@ -996,7 +998,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (hscale);
 
 
-  button = gtk_check_button_new_with_label (_ ("Create Charcoal Effect?"));
+  button = gtk_check_button_new_with_label (_ ("Create Charcoal Effect"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->charcoal);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) charcoal_cb, NULL);
@@ -1025,7 +1027,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (hscale);
 
 
-  button = gtk_check_button_new_with_label (_ ("Find Edges in Image?"));
+  button = gtk_check_button_new_with_label (_ ("Find Edges in Image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->edge);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) edge_cb, NULL);
@@ -1053,7 +1055,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_vbox_2), hscale, TRUE, TRUE, 0);
   gtk_widget_show (hscale);
 
-  button = gtk_check_button_new_with_label (_ ("Implode Image?"));
+  button = gtk_check_button_new_with_label (_ ("Implode Image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->implode);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) implode_cb, NULL);
@@ -1091,7 +1093,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 				  GNOME_PAD_SMALL);
 
 
-  button = gtk_check_button_new_with_label (_ ("Create Painted Effect?"));
+  button = gtk_check_button_new_with_label (_ ("Create Painted Effect"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->paint);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) paint_cb, NULL);
@@ -1119,7 +1121,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_vbox_2), hscale, TRUE, TRUE, 0);
   gtk_widget_show (hscale);
 
-  button = gtk_check_button_new_with_label (_ ("Solarize Image?"));
+  button = gtk_check_button_new_with_label (_ ("Solarise Image"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->solarize);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) solarize_cb, NULL);
@@ -1127,7 +1129,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
 		      0);
   gtk_widget_show (button);
 
-  frame = gtk_frame_new (_ ("Solarize Factor?"));
+  frame = gtk_frame_new (_ ("Solarize factor?"));
   gtk_box_pack_start (GTK_BOX (ad->spurious_pref_vbox2), frame, FALSE, FALSE,
 		      0);
   gtk_widget_show (frame);
@@ -1147,7 +1149,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_box_pack_start (GTK_BOX (pref_vbox_2), hscale, TRUE, TRUE, 0);
   gtk_widget_show (hscale);
 
-  button = gtk_check_button_new_with_label (_ ("Spread Image Pixels?"));
+  button = gtk_check_button_new_with_label (_ ("Spread image pixels"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->spread);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) spread_cb, NULL);
@@ -1176,7 +1178,7 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   gtk_widget_show (hscale);
 
   button =
-    gtk_check_button_new_with_label (_ ("Swirl Pixels? My favorite :-)"));
+    gtk_check_button_new_with_label (_ ("Swirl pixels. My favorite :-)"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), ad->swirl);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      (GtkSignalFunc) swirl_cb, NULL);
@@ -1231,6 +1233,9 @@ applet_save_session (GtkWidget * widget, gchar * privcfgpath,
 {
   properties_save (privcfgpath, NULL);
   return FALSE;
+  widget = NULL;
+  globcfgpath = NULL;
+  data = NULL;
 }
 
 int
@@ -1251,10 +1256,10 @@ main (int argc, char *argv[])
   int init_size;
 #endif
 
-  /* Initialize the i18n stuff 
-     bindtextdomain ("screenshooter_applet", GNOMELOCALEDIR);
-     textdomain ("screenshooter_applet");
-   */
+  /* Initialize the i18n stuff */
+  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+  textdomain (PACKAGE);
+
   applet_widget_init ("screenshooter_applet", VERSION, argc, argv, NULL, 0,
 		      NULL);
   applet = applet_widget_new ("screenshooter_applet");
@@ -1387,29 +1392,33 @@ void
 window_button_press (GtkWidget * button, user_preferences * opt)
 {
   grab_shot (opt, FALSE);
+  return;
+  button = NULL;
 }
 
 void
 desktop_button_press (GtkWidget * button, user_preferences * opt)
 {
   grab_shot (opt, TRUE);
+  return;
+  button = NULL;
 }
 
 void
 grab_shot (user_preferences * opt, gboolean root)
 {
-  gchar *sys=NULL;
+  gchar *sys = NULL;
   gchar qual_buf[10];
   gchar thumb_qual_buf[10];
-  gchar *dir_buf=NULL;
-  gchar *file_buf=NULL;
-  gchar *temp_dir_file_buf=NULL;
+  gchar *dir_buf = NULL;
+  gchar *file_buf = NULL;
+  gchar *temp_dir_file_buf = NULL;
   gchar dec_buf[10];
   gchar mono_buf[25];
   gchar neg_buf[15];
   gchar beep_buf[10];
   gchar delay_buf[15];
-  gchar *thumb_image=NULL;
+  gchar *thumb_image = NULL;
   wordexp_t mywordexp;
   int wordexpret = 0;
 
@@ -1563,7 +1572,7 @@ grab_shot (user_preferences * opt, gboolean root)
 		       "-window", "root", "-quality", qual_buf, lastimage,
 		       NULL);
     }
-  system(sys);
+  system (sys);
 
   if (opt->post_process)
     {
@@ -1826,6 +1835,41 @@ grab_shot (user_preferences * opt, gboolean root)
     }
 }
 
+void
+expand_cb (GtkWidget * w, gpointer data)
+{
+  wordexp_t mywordexp;
+  int wordexpret = 0;
+  gchar *filename = NULL;
+  gchar *message = NULL;
+  gchar *buf = NULL;
+
+  filename = gtk_entry_get_text (GTK_ENTRY (options.filename_entry));
+
+  if ((wordexpret = wordexp (filename, &mywordexp, 0) != 0))
+    {
+      gnome_ok_dialog (_ ("There was a word expansion error\n"
+			  "I think you have stuck something funny in the filename box"));
+      wordfree (&mywordexp);
+      return;
+    }
+  else
+    {
+      buf = g_strjoinv ("", mywordexp.we_wordv);
+
+      /* display expanded filename */
+      message = g_strdup_printf
+	(_
+	 ("The specified filename:\n%s\nexpands to:\n%s\nwhen passed to a shell"),
+	 filename, buf);
+      gnome_ok_dialog (message);
+      wordfree (&mywordexp);
+    }
+  return;
+  data = NULL;
+  w = NULL;
+}
+
 void
 property_apply_cb (GtkWidget * w, gpointer data)
 {
@@ -1834,8 +1878,11 @@ property_apply_cb (GtkWidget * w, gpointer data)
   gchar *buf;
   gint info_changed = FALSE;
 
-  buf = gtk_entry_get_text (GTK_ENTRY (
-    GTK_COMBO (GNOME_FILE_ENTRY (ad->directory_entry)->gentry)->entry));
+  buf =
+    gtk_entry_get_text (GTK_ENTRY
+			(GTK_COMBO
+			 (GNOME_FILE_ENTRY (ad->directory_entry)->
+			  gentry)->entry));
 
   if ((buf) && (strcmp (buf, old->directory)))
     {
@@ -1900,6 +1947,9 @@ property_apply_cb (GtkWidget * w, gpointer data)
       /* Re-copy options for next comparison */
       memcpy (&old_options, &options, sizeof (user_preferences));
     }
+  return;
+  w = NULL;
+  data = NULL;
 }
 
 void
@@ -1907,6 +1957,8 @@ quality_cb (GtkWidget * w, gpointer data)
 {
   options.quality = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1914,6 +1966,8 @@ gamma_factor_cb (GtkWidget * w, gpointer data)
 {
   options.gamma_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1921,6 +1975,8 @@ frame_size_cb (GtkWidget * w, gpointer data)
 {
   options.frame_size = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1928,6 +1984,8 @@ thumb_quality_cb (GtkWidget * w, gpointer data)
 {
   options.thumb_quality = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1935,6 +1993,8 @@ thumb_size_cb (GtkWidget * w, gpointer data)
 {
   options.thumb_size = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1942,12 +2002,17 @@ delay_cb (GtkWidget * w, gpointer data)
 {
   options.delay = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
 directory_button_pressed (GtkWidget * w, gpointer data)
 {
   gnome_ok_dialog ("I'll get there soon!");
+  return;
+  data = NULL;
+  w = NULL;
 }
 
 void
@@ -1955,6 +2020,8 @@ decoration_cb (GtkWidget * w, gpointer data)
 {
   options.decoration = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1962,6 +2029,8 @@ gamma_cb (GtkWidget * w, gpointer data)
 {
   options.gamma = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1969,6 +2038,8 @@ enhance_cb (GtkWidget * w, gpointer data)
 {
   options.enhance = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1976,6 +2047,8 @@ emboss_cb (GtkWidget * w, gpointer data)
 {
   options.emboss = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1983,6 +2056,8 @@ normalize_cb (GtkWidget * w, gpointer data)
 {
   options.normalize = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1990,6 +2065,8 @@ despeckle_cb (GtkWidget * w, gpointer data)
 {
   options.despeckle = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -1997,6 +2074,8 @@ equalize_cb (GtkWidget * w, gpointer data)
 {
   options.equalize = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2004,6 +2083,8 @@ flip_cb (GtkWidget * w, gpointer data)
 {
   options.flip = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2011,6 +2092,8 @@ flop_cb (GtkWidget * w, gpointer data)
 {
   options.flop = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2018,6 +2101,8 @@ frame_cb (GtkWidget * w, gpointer data)
 {
   options.frame = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2025,6 +2110,8 @@ thumbnail_intermediate_cb (GtkWidget * w, gpointer data)
 {
   options.thumbnail_intermediate = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2032,6 +2119,8 @@ thumb_cb (GtkWidget * w, gpointer data)
 {
   options.thumb = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2039,6 +2128,8 @@ monochrome_cb (GtkWidget * w, gpointer data)
 {
   options.monochrome = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2046,6 +2137,8 @@ negate_cb (GtkWidget * w, gpointer data)
 {
   options.negate = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2053,6 +2146,8 @@ beep_cb (GtkWidget * w, gpointer data)
 {
   options.beep = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2060,6 +2155,8 @@ use_script_cb (GtkWidget * w, gpointer data)
 {
   options.use_script = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2067,6 +2164,8 @@ view_cb (GtkWidget * w, gpointer data)
 {
   options.view = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 gint
@@ -2074,6 +2173,8 @@ property_destroy_cb (GtkWidget * w, gpointer data)
 {
   options.propwindow = NULL;
   return FALSE;
+  w = NULL;
+  data = NULL;
 }
 
 void
@@ -2081,6 +2182,8 @@ rotate_degrees_cb (GtkWidget * w, gpointer data)
 {
   options.rotate_degrees = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2088,6 +2191,8 @@ blur_factor_cb (GtkWidget * w, gpointer data)
 {
   options.blur_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2095,6 +2200,8 @@ charcoal_factor_cb (GtkWidget * w, gpointer data)
 {
   options.charcoal_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2102,6 +2209,8 @@ edge_factor_cb (GtkWidget * w, gpointer data)
 {
   options.edge_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2109,6 +2218,8 @@ implode_factor_cb (GtkWidget * w, gpointer data)
 {
   options.implode_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2116,6 +2227,8 @@ swirl_degrees_cb (GtkWidget * w, gpointer data)
 {
   options.swirl_degrees = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2123,6 +2236,8 @@ paint_radius_cb (GtkWidget * w, gpointer data)
 {
   options.paint_radius = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2130,6 +2245,8 @@ sharpen_factor_cb (GtkWidget * w, gpointer data)
 {
   options.sharpen_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2137,6 +2254,8 @@ solarize_factor_cb (GtkWidget * w, gpointer data)
 {
   options.solarize_factor = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2144,6 +2263,8 @@ spread_radius_cb (GtkWidget * w, gpointer data)
 {
   options.spread_radius = GTK_ADJUSTMENT (w)->value;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2151,6 +2272,8 @@ blur_cb (GtkWidget * w, gpointer data)
 {
   options.blur = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2158,6 +2281,8 @@ charcoal_cb (GtkWidget * w, gpointer data)
 {
   options.charcoal = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2165,6 +2290,8 @@ edge_cb (GtkWidget * w, gpointer data)
 {
   options.edge = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2172,6 +2299,8 @@ implode_cb (GtkWidget * w, gpointer data)
 {
   options.implode = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2179,6 +2308,8 @@ paint_cb (GtkWidget * w, gpointer data)
 {
   options.paint = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2186,6 +2317,8 @@ solarize_cb (GtkWidget * w, gpointer data)
 {
   options.solarize = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2193,6 +2326,8 @@ swirl_cb (GtkWidget * w, gpointer data)
 {
   options.swirl = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2200,6 +2335,8 @@ spread_cb (GtkWidget * w, gpointer data)
 {
   options.spread = GTK_TOGGLE_BUTTON (w)->active;
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
 
 void
@@ -2219,4 +2356,6 @@ spurious_cb (GtkWidget * w, gpointer data)
       gtk_widget_hide (options.spurious_pref_vbox3);
     }
   gnome_property_box_changed (GNOME_PROPERTY_BOX (options.propwindow));
+  return;
+  data = NULL;
 }
